#!/bin/sh
#
# Runtime provisioning script for Vagrant-based training lab setup

# Location of the runtime files. MANIFEST must exist there, and
# describes what else needs to be downloaded: in the format:
# <FILENAME>:<BYTES>:<SHA256>
# Apart from the MANIFEST itself, all files should be compressed with
# gzip. In each case, the script will download $FILENAME.gz,
# decompress it and then validate the checksum
RUNTIME_DL=https://www.einval.com/arm/training-lab/

# Abort on errors
set -e
# set -x

# Make sure we have updates applied, and all our needed packages
apt-get update
apt-get dist-upgrade -y
apt-get install -y qemu-system-arm gcc-aarch64-linux-gnu
echo "Toolchain VM running!"

# Now grab the emulated runtime and start that
cd /vagrant
if [ ! -d runtime ]; then
    mkdir runtime
fi
cd runtime

echo "Checking / downloading files needed for the emulated runtime VM"
# Grab all the files we need, and check they're valid
echo "  Downloading MANIFEST"
wget -nv -O MANIFEST $RUNTIME_DL/MANIFEST 
for LINE in $(cat MANIFEST); do
    FILENAME=$(echo $LINE | awk -F: '{print $1}')
    MODE=$(echo $LINE | awk -F: '{print $2}')
    BYTES=$(echo $LINE | awk -F: '{print $3}')
    SHA=$(echo $LINE | awk -F: '{print $4}')
    DL_NEEDED=1
    
    # Quick and dirty - if the file exists and is the right size,
    # we'll believe it
    echo "  Checking $FILENAME.gz"
    if [ -f $FILENAME ]; then
        SIZE=$(stat -c%s $FILENAME)
        if [ $SIZE = $BYTES ]; then
            DL_NEEDED=0
        fi
    fi

    if [ $DL_NEEDED = 1 ]; then
        # Grab a compressed version of the file, and extract it as we
        # go
        echo "  Downloading $FILENAME.gz"
        wget -nv -O- $RUNTIME_DL/$FILENAME.gz | gzip -cd > $FILENAME
        SHA_FILE=$(sha256sum $FILENAME | awk '{print $1}')
        if [ $SHA_FILE != $SHA ]; then
            echo "Failed to download $FILENAME.gz correctly. Abort"
            exit 1
        fi
    fi
    chmod $MODE $FILENAME
done

echo "Starting emulated runtime VM next"
./start_runtime
